@@ -17,7 +17,7 @@ from dbnd._core.tracking.script_tracking_manager import (
 from dbnd._core.utils.basics.environ_utils import env
 from dbnd_airflow.tracking.config import AirflowTrackingConfig
 from dbnd_airflow.tracking.dbnd_airflow_conf import get_tracking_information, get_xcoms
-from dbnd_airflow.tracking.wrap_operators import add_tracking_to_submit_task
+from dbnd_airflow.tracking.wrap_operators import wrap_operator_with_tracking_info
 
 
 logger = logging.getLogger(__name__)
@@ -50,7 +50,7 @@ def new_execute(context):
 
     # running the operator's original execute function
     try:
-        with tracking_context(task_run, context, copied_operator):
+        with af_tracking_context(task_run, context, copied_operator):
             execute = get_execute_function(copied_operator)
             result = execute(copied_operator, context)
 
@@ -111,7 +111,7 @@ def log_operator_result(task_run, result, operator, track_xcom):
 
 
 @contextmanager
-def tracking_context(task_run, airflow_context, operator):
+def af_tracking_context(task_run, airflow_context, operator):
     """
     Wrap the execution with handling the environment management
     """
@@ -122,7 +122,7 @@ def tracking_context(task_run, airflow_context, operator):
 
     try:
         tracking_info = get_tracking_information(airflow_context, task_run)
-        add_tracking_to_submit_task(tracking_info, operator)
+        wrap_operator_with_tracking_info(tracking_info, operator)
 
     except Exception as e:
         logger.error(
@@ -134,7 +134,6 @@ def tracking_context(task_run, airflow_context, operator):
         return
 
     # wrap the execution with tracking info in the environment
-    # and cleaning when done
     with env(**tracking_info):
         yield
 
